@@ -3,10 +3,21 @@ use Moose;
 
 extends 'Chart::Clicker::Renderer::Base';
 
-use Cairo;
-
+use Chart::Clicker::Drawing::Color;
+use Chart::Clicker::Drawing::Stroke;
 use Chart::Clicker::Shape::Arc;
 
+has 'border_color' => (
+    is => 'rw',
+    isa => 'Chart::Clicker::Drawing::Color',
+    default => sub { new Chart::Clicker::Drawing::Color({ name => 'black' }) }
+);
+has 'stroke' => (
+    is => 'rw',
+    isa => 'Chart::Clicker::Drawing::Stroke',
+    default => sub { new Chart::Clicker::Drawing::Stroke() }
+);
+
 my $TO_RAD = (4 * atan2(1, 1)) / 180;
 
 sub prepare {
@@ -28,11 +39,15 @@ sub prepare {
     if($self->width() < $self->height()) {
         $self->{'RADIUS'} = $self->width();
     }
+
     $self->{'RADIUS'} = $self->{'RADIUS'} / 2;
 
+    # Take into acount the line around the edge when working out the radius
+    $self->{RADIUS} -= $self->stroke->width();
+
     $self->{'MIDX'} = $self->width() / 2;
     $self->{'MIDY'} = $self->height() / 2;
-    $self->{'POS'} = 0;
+    $self->{'POS'} = -90;
 }
 
 sub draw {
@@ -46,65 +61,31 @@ sub draw {
     my $height = $self->height();
     my $linewidth = 1;
 
-    my $stroke = $self->get_option('stroke');
-    if($stroke) {
-        $linewidth = $stroke->width();
-        $cr->set_line_cap($stroke->line_cap());
-        $cr->set_line_join($stroke->line_join());
-    }
-    $cr->set_line_width($linewidth);
-
-    my $bcolor = $self->get_option('border_color');# = $clicker->color_allocator->next();
-    if(!$bcolor) {
-        $bcolor = new Chart::Clicker::Drawing::Color({ name => 'black' });
-    }
-
-    #my @vals = @{ $series->values() };
-    #my @keys = @{ $series->keys() };
-
-    # my $kcount = $series->key_count() - 1;
-    # 
-    # my %accum;
-    # my $total;
-    # for(0..$kcount) {
-    #     #my $x = $domain->mark($keys[$_]);
-    #     #my $y = $height - $range->mark($vals[$_]);
-    #     $accum{$keys[$_]} += $vals[$_];
-    #     $total += $vals[$_];
-    # }
+    $cr->set_line_cap($self->stroke->line_cap());
+    $cr->set_line_join($self->stroke->line_join());
+    $cr->set_line_width($self->stroke->width());
 
     my $midx = $self->{'MIDX'};
     my $midy = $self->{'MIDY'};
 
-    # my $pos = 0;
-    #foreach my $key (keys(%accum)) {
-        my $avg = $self->{'ACCUM'}->{$series->name()} / $self->{'TOTAL'};
-        my $degs = ($avg * 360) + $self->{'POS'};
-        # my $arc = new Chart::Clicker::Shape::Arc({
-        #     angle1  => $self->{'POS'},
-        #     angle2  => $degs,
-        #     radius  => $self->{'RADIUS'}
-        # });
-        # $arc->create_path($cr, $midx, $midy);
+    my $avg = $self->{'ACCUM'}->{$series->name()} / $self->{'TOTAL'};
+    my $degs = ($avg * 360) + $self->{'POS'};
 
-        $cr->line_to($midx, $midy);
-        #$arc->angle1($degs);
-        #$arc->angle2($self->{'POS'});
+    $cr->line_to($midx, $midy);
 
-        $cr->arc_negative($midx, $midy, $self->{'RADIUS'}, $degs * $TO_RAD, $self->{'POS'} * $TO_RAD);
-        $cr->line_to($midx, $midy);
-        $cr->close_path();
+    $cr->arc_negative($midx, $midy, $self->{'RADIUS'}, $degs * $TO_RAD, $self->{'POS'} * $TO_RAD);
+    $cr->line_to($midx, $midy);
+    $cr->close_path();
 
-        my $color = $clicker->color_allocator->next();
+    my $color = $clicker->color_allocator->next();
 
-        $cr->set_source_rgba($color->rgba());
-        $cr->fill_preserve();
+    $cr->set_source_rgba($color->rgba());
+    $cr->fill_preserve();
 
-        $cr->set_source_rgba($bcolor->rgba());
-        $cr->stroke();
+    $cr->set_source_rgba($self->border_color->rgba());
+    $cr->stroke();
 
-        $self->{'POS'} = $degs;
-    #}
+    $self->{'POS'} = $degs;
 
     return 1;
 }
